@@ -1,5 +1,8 @@
+"""
+Module containing configuration classes used for configuring the algoralabs sdk
+"""
 import os
-from typing import Optional, DefaultDict
+from typing import Optional, Dict
 
 from algoralabs.decorators.configuration import configuration
 from algoralabs.gData import config_file
@@ -7,6 +10,9 @@ from algoralabs.gData import config_file
 
 @configuration
 class Auth:
+    """
+    Configuration class for getting the authentication information from the environment
+    """
     # Feature to keep values hidden from printing (not totally)
     # Allows for dynamic rendering of auth values
     @property
@@ -22,12 +28,18 @@ class Auth:
         return os.getenv("AUTH_TOKEN", None)
 
     def can_authenticate(self) -> bool:
+        """
+        Tests the environment to see if the user provided enough info to authenticate requests
+
+        Returns:
+            A boolean that represents whether you can authenticate requests
+        """
         auth_options = self.token or (self.username and self.password)
         return auth_options is not None
 
-    def __eq__(self, other):
+    def __eq__(self, other: "Auth"):
         return (
-            self.token == other.toker and
+            self.token == other.token and
             self.username == self.username and
             self.password == self.password
         )
@@ -35,6 +47,9 @@ class Auth:
 
 @configuration(yaml_file=config_file, prefix="")
 class AppConfig:
+    """
+    Configuration class for getting app information
+    """
     app_name: str
     environment: str
     version: str
@@ -45,9 +60,12 @@ app_config = AppConfig()
 
 @configuration(yaml_file=config_file, prefix=app_config.environment)
 class EnvironmentConfig:
+    """
+    Configuration class for getting environment information
+    """
     urls: dict
     auth_config: Auth = Auth()
 
-    def get_url(self, key="algora"):
+    def get_url(self, key: str = "algora") -> str:
         return self.urls.get(key, self.urls["algora"])
 
