@@ -1,8 +1,9 @@
 """
 Module containing helpful functions
 """
-import dataclasses
 import calendar
+import dataclasses
+from datetime import datetime
 from functools import reduce
 from typing import Dict, Any, Union, List, Optional
 
@@ -95,5 +96,17 @@ def no_transform(data: Dict[str, Any]) -> Dict[str, Any]:
     return data
 
 
+def timestamp_to_datetime(timestamp: int) -> datetime:
+    """
+    Epoch timestamp to datetime.
+
+    Args:
+        timestamp: Epoch timestamp in milliseconds.
+
+    Returns: Datetime
+    """
+    return datetime.fromtimestamp(timestamp / 1000)
+
+
 def date_to_timestamp(date: Datetime) -> int:
     return calendar.timegm(date.timetuple()) * 1000
